@@ -8,11 +8,16 @@ import lightwood
 # HORRIBLE HACK TO AVOID SEGFAULT
 # @TODO: FIND A WAY TO ACTUALLY SOLVE THIS ASAP !!!
 
+from mindsdb_native.libs.controllers import functional
+F = functional
+
 from mindsdb_native.config import CONFIG
 import mindsdb_native.libs.constants.mindsdb as CONST
 
 from mindsdb_native.__about__ import __package_name__ as name, __version__
 from mindsdb_native.libs.controllers.predictor import Predictor
+from mindsdb_native.libs.data_sources.maria_ds import MariaDS
+from mindsdb_native.libs.data_sources.mysql_ds import MySqlDS
 
 # Data Sources
 from mindsdb_native.libs.data_sources.file_ds import FileDS
@@ -22,17 +27,6 @@ try:
 except:
     pass
 
-try:
-    from mindsdb_native.libs.data_sources.maria_ds import MariaDS
-except:
-    print("MariaDS Datasource is not available by default. If you wish to use it, please install mariadb or mindsdb[extra_data_sources]")
-
-
-try:
-    from mindsdb_native.libs.data_sources.mysql_ds import MySqlDS
-except:
-    print("MySQL Datasource is not available by default. If you wish to use it, please install mysqlclient or mindsdb[extra_data_sources]")
-
 try:
     from mindsdb_native.libs.data_sources.postgres_ds import PostgresDS
 except:
@@ -42,4 +36,6 @@ except:
 
 from mindsdb_native.libs.data_sources.clickhouse_ds import ClickhouseDS
 
+
+
 MindsDB = Predictor
